import React, { useEffect, useRef } from 'react'
import { getCurrentInstance } from '@tarojs/taro'
import { useModel } from '@/store'
import request, { apis } from '../request'

const pages = require('../../pages')

/**
 * 页面埋点
 * params 一般不需要传值,
 * 特殊情况, 可以参考 ta_person_visit 表
 * 
 * @param {*} params 
 */
export default function useMountTrack(params) {
  const execed = useRef(false)
  const { user } = useModel('user')

  useEffect(() => {
    if (!user || !user.personId) {
      return
    }

    const router = getCurrentInstance().router
    const page = pages.filter(x => router.path.indexOf(x.page) > -1)[0]
    if (!page) {
      return
    }

    // 只执行一次
    if (execed.current) {
      return
    } else {
      execed.current = true
    }

    const data = {
      propertyName: page.name,
      data: '{}',
      ...page.track,
      ...(params || {})
    }

    let id = undefined
    request({ ...apis.saveTracking, silent: true, data }).then(res => {
      id = res.recordId
    })

    return () => id && request({ ...apis.updateTracking, silent: true, args: { id } })
  }, [params, user])
}
